@@ -1,11 +1,5 @@
 #include "save.h"
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-dialog-util.h>
-#include <libgnomeui/gnome-uidefs.h>
-#include <gtk/gtkfilesel.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <libgnome/libgnome.h>
+#include <gnome.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -22,9 +16,9 @@ actual_save_theme (MtmTheme *theme)
 	res = mtm_theme_save (theme);
 	if (res != MTM_OK)
 	{
-		GtkWidget *dlg = gnome_error_dialog (_("Unable to save the metatheme. Please check to make sure you have write permissions to the directory specified."));
+		GtkWidget *dlg = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Unable to save the metatheme. Please check to make sure you have write permissions to the directory specified."));
 		gtk_widget_show (dlg);
-		gnome_dialog_run (GNOME_DIALOG (dlg));
+		gtk_dialog_run (GTK_DIALOG (dlg));
 		mtm_theme_set_filename (theme, NULL);
 	}
 }
@@ -37,7 +31,12 @@ is_writable (const gchar* filename)
 	g_return_val_if_fail (filename != NULL, FALSE);
 
 	if (stat (filename, &stbuf) != 0)
-		return is_writable (g_dirname (filename));
+	{
+		gchar *name = g_path_get_dirname (filename);
+		gboolean ret = is_writable (name);
+		g_free (name);
+		return ret;
+	}
 	else if (!((getuid () == stbuf.st_uid && (stbuf.st_mode & S_IWUSR))
 		|| (getgid () == stbuf.st_gid && (stbuf.st_mode & S_IWGRP))
 		|| (stbuf.st_mode & S_IWOTH)))
@@ -73,7 +72,7 @@ fsel_ok_cb (GtkWidget *button, MtmTheme *theme)
 	
 	g_return_if_fail (MTM_IS_THEME (theme));
 
-	fsel = gtk_object_get_data (GTK_OBJECT (theme), "fsel");
+	fsel = g_object_get_data (G_OBJECT (theme), "fsel");
 	mtm_theme_set_filename (theme, gtk_file_selection_get_filename (fsel));
 	gtk_main_quit ();
 }
@@ -87,13 +86,13 @@ save_theme_as (MtmTheme *theme)
 	g_return_if_fail (MTM_IS_THEME (theme));
 
 	fsel = gtk_file_selection_new (NULL);
-	gtk_signal_connect (GTK_OBJECT (fsel), "delete_event",
-			    fsel_cancel_cb, &cancelled);
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (fsel)->cancel_button),
-			    "clicked", fsel_cancel_cb, &cancelled);
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (fsel)->ok_button),
-			    "clicked", fsel_ok_cb, theme);
-	gtk_object_set_data (GTK_OBJECT (theme), "fsel", fsel);
+	g_signal_connect (G_OBJECT (fsel), "delete_event",
+			  (GCallback) fsel_cancel_cb, &cancelled);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (fsel)->cancel_button),
+			  "clicked", (GCallback) fsel_cancel_cb, &cancelled);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (fsel)->ok_button),
+			  "clicked", (GCallback) fsel_ok_cb, theme);
+	g_object_set_data (G_OBJECT (theme), "fsel", fsel);
 		
 	gtk_widget_show (fsel);
 	
@@ -107,7 +106,7 @@ save_theme_as (MtmTheme *theme)
 static void
 mod_reply_cb (GtkWidget *dlg, gint reply, gboolean *do_save)
 {
-	if (reply == GNOME_YES)
+	if (reply == GTK_RESPONSE_YES)
 		*do_save = TRUE;
 	else
 		*do_save = FALSE;
@@ -120,10 +119,14 @@ run_modified_dlg (MtmTheme *theme)
 	gboolean do_save;
 
 	g_return_if_fail (MTM_IS_THEME (theme));
-	dlg = gnome_question_dialog (_("Theme unsaved. Save before exiting?"),
-				     mod_reply_cb, &do_save);
+	dlg = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_QUESTION,
+				      GTK_BUTTONS_YES_NO,
+				     _("Theme unsaved. Save before exiting?"));
+	g_signal_connect (G_OBJECT (dlg), "response",
+			  (GCallback) mod_reply_cb, &do_save);
 	gtk_widget_show (dlg);
-	gnome_dialog_run (GNOME_DIALOG (dlg));
+	gtk_dialog_run (GTK_DIALOG (dlg));
 	
 	if (do_save)
 		save_theme (theme);
